==> lesstif_0.50.orig.tar.gz: lesstif-0.50.orig/include/Xm/LabelP.h <==
/**
 *
 * $Id: LabelP.h,v 1.4 1996/04/03 06:29:07 u27113 Exp $
 *
 * Copyright (C) 1995 Free Software Foundation, Inc.
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef XM_LABEL_P_H
#define XM_LABEL_P_H

#include <Xm/Label.h>
#include <Xm/PrimitiveP.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifndef XmUNSPECFIED
#define XmUNSPECIFIED	(~0)
#endif

#define LABEL_ACC_PAD	15

typedef struct {
    XmString _label;
    XmString _acc_text;
    KeySym mnemonic;
    XmStringCharSet mnemonicCharset;
    String accelerator;
    unsigned char label_type;
    unsigned char alignment;
    XmStringDirection string_direction;
    XmFontList font;

    Dimension margin_height;
    Dimension margin_width;

    Dimension margin_left;
    Dimension margin_right;
    Dimension margin_top;
    Dimension margin_bottom;

    Boolean recompute_size;

    Pixmap pixmap;
    Pixmap pixmap_insen;
 
    /* private instance variables */

    GC normal_GC;
    GC insensitive_GC;

    XRectangle TextRect;
    XRectangle acc_TextRect;

    Boolean skipCallback;

    unsigned char menu_type;  /* if inside a RowColumn, its row_column_type */
} XmLabelPart;

/* Define the full instance record */
typedef struct _XmLabelRec {
    CorePart core;
    XmPrimitivePart primitive;
    XmLabelPart label;
} XmLabelRec;

/* Define class part structure */
typedef struct {
    XtWidgetProc setOverrideCallback;
    XmMenuProc menuProcs;
    String translations;
    XtPointer extension;
} XmLabelClassPart;

/* Define the full class record */
typedef struct _XmLabelClassRec {
    CoreClassPart core_class;
    XmPrimitiveClassPart primitive_class;
    XmLabelClassPart label_class;
} XmLabelClassRec;

/* External definition for class record */

extern XmLabelClassRec xmLabelClassRec;

/* private prototypes */

void _XmCalcLabelDimensions(Widget w);

#ifdef __cplusplus
};
#endif

#define Lab_LabelType(w) \
       (((XmLabelWidget)(w))->label.label_type)

#define Lab_MarginWidth(w) \
       (((XmLabelWidget)(w))->label.margin_width)

#define Lab_MarginHeight(w) \
       (((XmLabelWidget)(w))->label.margin_height)

#define Lab_MarginTop(w) \
       (((XmLabelWidget)(w))->label.margin_top)

#define Lab_MarginBottom(w) \
       (((XmLabelWidget)(w))->label.margin_bottom)

#define Lab_MarginRight(w) \
       (((XmLabelWidget)(w))->label.margin_right)

#define Lab_RecomputeSize(w) \
       (((XmLabelWidget)(w))->label.recompute_size)

#define Lab_MarginLeft(w) \
       (((XmLabelWidget)(w))->label.margin_left)

#define Lab_TextRect_x(w) \
       (((XmLabelWidget)(w))->label.TextRect.x)

#define Lab_TextRect_y(w) \
       (((XmLabelWidget)(w))->label.TextRect.y)

#define Lab_TextRect_width(w) \
       (((XmLabelWidget)(w))->label.TextRect.width)

#define Lab_TextRect_height(w) \
       (((XmLabelWidget)(w))->label.TextRect.height)

#define Lab_IsText(w) \
       (((XmLabelWidget)(w))->label.label_type == XmSTRING)

#define Lab_IsPixmap(w) \
       (((XmLabelWidget)(w))->label.label_type == XmPIXMAP)

#define Lab_Font(w) \
       (((XmLabelWidget)(w))->label.font)

#define Lab_Label(w) \
       (((XmLabelWidget)(w))->label._label)

#define Lab_Mnemonic(w) \
       (((XmLabelWidget)(w))->label.mnemonic)

#define Lab_MnemonicCharset(w) \
       (((XmLabelWidget)(w))->label.mnemonicCharset)

#define Lab_Accelerator(w) \
       (((XmLabelWidget)(w))->label.accelerator)

#define Lab_AcceleratorText(w) \
       (((XmLabelWidget)(w))->label._acc_text)

#define Lab_MenuType(w) \
       (((XmLabelWidget)(w))->label.menu_type)

#define Lab_Alignment(w) \
       (((XmLabelWidget)(w))->label.alignment)

#define Lab_Pixmap(w) \
       (((XmLabelWidget)(w))->label.pixmap)

#define Lab_PixmapInsensitive(w) \
       (((XmLabelWidget)(w))->label.pixmap_insen)

#define Lab_NormalGC(w) \
       (((XmLabelWidget)(w))->label.normal_GC)

#define Lab_InsensitiveGC(w) \
       (((XmLabelWidget)(w))->label.insensitive_GC)

#define Lab_Shadow(w) \
       Prim_ShadowThickness(w)

#define Lab_StringDirection(w) \
       (((XmLabelWidget)(w))->label.string_direction)

#define Lab_Highlight(w) \
       Prim_HighlightThickness(w)

#define Lab_Baseline(w) \
       (XmStringBaseline ( \
               ((XmLabelWidget)(w))->label.font,\
               ((XmLabelWidget)(w))->label._label))

#define Lab_AccTextRect(w) \
       (((XmLabelWidget)(w))->label.acc_TextRect)


#endif /* XM_LABEL_P_H */

==> lesstif_0.76.orig.tar.gz: lesstif-0.76.orig/include/Xm/LabelP.h <==
/**
 *
 * $Id: LabelP.h,v 1.6 1996/09/25 02:14:51 miers Exp $
 *
 * Copyright (C) 1995 Free Software Foundation, Inc.
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef XM_LABEL_P_H
#define XM_LABEL_P_H

#include <Xm/Label.h>
#include <Xm/PrimitiveP.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifndef XmUNSPECFIED
#define XmUNSPECIFIED	(~0)
#endif

#define LABEL_ACC_PAD	15

typedef struct {
    _XmString _label;
    _XmString _acc_text;
    KeySym mnemonic;
    XmStringCharSet mnemonicCharset;
    String accelerator;
    unsigned char label_type;
    unsigned char alignment;
    XmStringDirection string_direction;
    XmFontList font;

    Dimension margin_height;
    Dimension margin_width;

    Dimension margin_left;
    Dimension margin_right;
    Dimension margin_top;
    Dimension margin_bottom;

    Boolean recompute_size;

    Pixmap pixmap;
    Pixmap pixmap_insen;
 
    /* private instance variables */

    GC normal_GC;
    GC insensitive_GC;

    XRectangle TextRect;
    XRectangle acc_TextRect;

    Boolean skipCallback;

    unsigned char menu_type;  /* if inside a RowColumn, its row_column_type */
} XmLabelPart;

/* Define the full instance record */
typedef struct _XmLabelRec {
    CorePart core;
    XmPrimitivePart primitive;
    XmLabelPart label;
} XmLabelRec;

/* Define class part structure */
typedef struct {
    XtWidgetProc setOverrideCallback;
    XmMenuProc menuProcs;
    String translations;
    XtPointer extension;
} XmLabelClassPart;

/* Define the full class record */
typedef struct _XmLabelClassRec {
    CoreClassPart core_class;
    XmPrimitiveClassPart primitive_class;
    XmLabelClassPart label_class;
} XmLabelClassRec;

/* External definition for class record */

extern XmLabelClassRec xmLabelClassRec;

/* private prototypes */

void _XmCalcLabelDimensions(Widget w);

#define Lab_MarginWidth(w) \
       (((XmLabelWidget)(w))->label.margin_width)

#define Lab_MarginHeight(w) \
       (((XmLabelWidget)(w))->label.margin_height)

#define Lab_MarginTop(w) \
       (((XmLabelWidget)(w))->label.margin_top)

#define Lab_MarginBottom(w) \
       (((XmLabelWidget)(w))->label.margin_bottom)

#define Lab_MarginRight(w) \
       (((XmLabelWidget)(w))->label.margin_right)

#define Lab_MarginLeft(w) \
       (((XmLabelWidget)(w))->label.margin_left)

#define Lab_TextRect_x(w) \
       (((XmLabelWidget)(w))->label.TextRect.x)

#define Lab_TextRect_y(w) \
       (((XmLabelWidget)(w))->label.TextRect.y)

#define Lab_TextRect_width(w) \
       (((XmLabelWidget)(w))->label.TextRect.width)

#define Lab_TextRect_height(w) \
       (((XmLabelWidget)(w))->label.TextRect.height)

#define Lab_IsText(w) \
       (((XmLabelWidget)(w))->label.label_type == XmSTRING)

#define Lab_IsPixmap(w) \
       (((XmLabelWidget)(w))->label.label_type == XmPIXMAP)

#define Lab_Font(w) \
       (((XmLabelWidget)(w))->label.font)

#define Lab_Mnemonic(w) \
       (((XmLabelWidget)(w))->label.mnemonic)

#define Lab_Accelerator(w) \
       (((XmLabelWidget)(w))->label.accelerator)

#define Lab_AcceleratorText(w) \
       (((XmLabelWidget)(w))->label._acc_text)

#define Lab_MenuType(w) \
       (((XmLabelWidget)(w))->label.menu_type)

#define Lab_Shadow(w) \
       Prim_ShadowThickness(w)

#define Lab_Highlight(w) \
       Prim_HighlightThickness(w)

#define Lab_Baseline(w) \
       (XmStringBaseline ( \
               ((XmLabelWidget)(w))->label.font,\
               ((XmLabelWidget)(w))->label._label))

#ifdef __cplusplus
}
#endif

#endif /* XM_LABEL_P_H */
